==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Weergave</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Afgeschuinde randen</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Slagschaduwen</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Kleuren</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Achtergrond:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Schaduw:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Markering:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Ontbrekende afbeelding.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Even geduld</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Bezig met laden van afbeelding...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Bezig met genereren van puzzel...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Bezig met creëren van stukken...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Bezig met laden van puzzel...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Onbekend gegevensformaat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Onbekend element &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Fout tijdens inlezen van XML-bestand.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Bezig met laden van stukken...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Bezig met ophalen van stukken...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Bezig met plaatsen van stukken...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Voltooid</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Kies spel</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Huidige spellen</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Afbeeldingseigenschappen</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Labels:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer de applicatietaal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart de applicatie om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Afbeelding toevoegen</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Afbeelding verwijderen</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Afbeeldingseigenschappen</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 stukken</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Bezig met kopiëren van afbeeldingen...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Geselecteerde afbeelding verwijderen?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Geselecteerde afbeelding verwijderen?

De opgeslagen spellen die deze afbeelding gebruiken worden ook verwijderd.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 stukken %2 %3% klaar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Spel verwijderen</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Geselecteerd spel verwijderen?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Overzicht</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Label toevoegen</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Label verwijderen</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Ongelabeld</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Alle afbeeldingen</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Naamloos %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Geselecteerd label verwijderen?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Er bestaat al een label met die naam.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Stukken ophalen</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Kiezen...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Beeld</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Inzoomen</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uitzoomen</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Beste inpassing</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>O&amp;verzicht weergeven</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>Weerg&amp;ave...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>Taa&amp;l...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Besturing</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Besturing</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken oppakken:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Linkermuisklik of spatiebalk</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken plaatsen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken selecteren:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Links slepen</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken draaien:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Rechtermuisklik, Control + linkermuisklik of R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzel verslepen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Middelste muisklik, Shift + linkermuisklik of pijltjestoetsen</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzel in-/uitzoomen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Scrolwiel of +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Cursor verplaatsen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Muis verplaatsen of W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Over Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Een legpuzzel met tetrominovormige stukken</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgegeven onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Selecteer OpenGL-versie.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versie</translation>
    </message>
</context>
</TS>

==> tetzle_2.2.0.orig.tar.gz: tetzle-2.2.0/translations/tetzle_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Schuine randen</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Slagschaduwen</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Kleuren</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Achtergrond:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Schaduw:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Markering:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Ontbrekende afbeelding.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Even geduld</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Bezig met laden van afbeelding…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Bezig met samenstellen van puzzel…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Bezig met maken van stukken…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Bezig met laden van puzzel…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Onbekend gegevensformaat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Onbekend element: &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Het xml-bestand kan niet worden ingelezen.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Bezig met laden van stukken…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Bezig met ophalen van stukken…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Bezig met plaatsen van stukken…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Voltooid</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Kies een spel</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Huidige spellen</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Afbeeldingseigenschappen</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Labels:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Kies de programmataal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart het programma om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Afbeelding toevoegen</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Afbeelding verwijderen</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Afbeeldingseigenschappen</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 stukken</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Bezig met kopiëren van afbeeldingen…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Geselecteerde afbeelding verwijderen?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Wil je de geselecteerde afbeelding verwijderen?

De opgeslagen spellen die deze afbeelding gebruiken worden eveneens verwijderd.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 stukken %2 %3% voltooid</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Spel verwijderen</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Geselecteerd spel verwijderen?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Overzicht</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Label toekennen</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Label verwijderen</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Ongelabeld</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Alle afbeeldingen</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Naamloos %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Geselecteerd label verwijderen?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Er is al een label met die naam.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Stukken ophalen</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Kiezen…</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Beeld</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Inzoomen</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Uitz&amp;oomen</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Beste inpassing</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>O&amp;verzicht tonen</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Beeld&amp;vullend</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>Vormg&amp;eving…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>Taa&amp;l…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Besturing</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Besturing</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken oppakken:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Linkermuisklik of spatiebalk</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken plaatsen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken selecteren:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Links slepen</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stukken draaien:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Rechtermuisklik, Ctrl + linkermuisklik of R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzel verslepen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Middelste muisklik, Shift + linkermuisklik of pijltjestoetsen</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzel in-/uitzoomen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Scrollwiel of +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Cursor verplaatsen:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Muis verplaatsen of W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Over Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Een legpuzzel met tetrominovormige stukken</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Kies de OpenGL-versie.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versie</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
